@@ -36,7 +36,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddUserContact", params)
+            headers = request.headers
+            body = self.call("AddUserContact", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddUserContactResponse()
@@ -54,6 +55,35 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CancelKillTask(self, request):
+        """终止中断会话任务。
+
+        :param request: Request instance for CancelKillTask.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.CancelKillTaskRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.CancelKillTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CancelKillTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CancelKillTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateDBDiagReportTask(self, request):
         """创建健康报告，并可以选择是否发送邮件。
 
@@ -64,7 +94,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBDiagReportTask", params)
+            headers = request.headers
+            body = self.call("CreateDBDiagReportTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBDiagReportTaskResponse()
@@ -92,7 +123,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBDiagReportUrl", params)
+            headers = request.headers
+            body = self.call("CreateDBDiagReportUrl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBDiagReportUrlResponse()
@@ -110,6 +142,35 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateKillTask(self, request):
+        """创建中断会话的任务。
+
+        :param request: Request instance for CreateKillTask.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.CreateKillTaskRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.CreateKillTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateKillTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateKillTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateMailProfile(self, request):
         """创建邮件配置。其中入参ProfileType表示所创建配置的类型，ProfileType 取值包括：dbScan_mail_configuration（数据库巡检邮件配置）、scheduler_mail_configuration（定期生成健康报告的邮件发送配置）。Region统一选择广州，和实例所属地域无关。
 
@@ -120,7 +181,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateMailProfile", params)
+            headers = request.headers
+            body = self.call("CreateMailProfile", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateMailProfileResponse()
@@ -138,6 +200,35 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateProxySessionKillTask(self, request):
+        """创建中止所有代理节点连接会话的异步任务。当前仅支持 Redis。得到的返回值为异步任务 id，可以作为参数传入接口 DescribeProxySessionKillTasks 查询kill会话任务执行状态。
+
+        :param request: Request instance for CreateProxySessionKillTask.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.CreateProxySessionKillTaskRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.CreateProxySessionKillTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateProxySessionKillTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateProxySessionKillTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSchedulerMailProfile(self, request):
         """该接口用于创建定期生成健康报告并邮件发送的配置，将健康报告的定期生成时间作为参数传入（周一至周日），用于设置健康报告的定期生成时间，同时保存相应的定期邮件发送的配置。
 
@@ -148,7 +239,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSchedulerMailProfile", params)
+            headers = request.headers
+            body = self.call("CreateSchedulerMailProfile", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSchedulerMailProfileResponse()
@@ -176,7 +268,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSecurityAuditLogExportTask", params)
+            headers = request.headers
+            body = self.call("CreateSecurityAuditLogExportTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSecurityAuditLogExportTaskResponse()
@@ -194,6 +287,35 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateSqlFilter(self, request):
+        """创建实例SQL限流任务。
+
+        :param request: Request instance for CreateSqlFilter.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.CreateSqlFilterRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.CreateSqlFilterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSqlFilter", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateSqlFilterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteSecurityAuditLogExportTasks(self, request):
         """删除安全审计日志导出任务。
 
@@ -204,7 +326,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSecurityAuditLogExportTasks", params)
+            headers = request.headers
+            body = self.call("DeleteSecurityAuditLogExportTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSecurityAuditLogExportTasksResponse()
@@ -222,6 +345,35 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteSqlFilters(self, request):
+        """删除实例SQL限流任务。
+
+        :param request: Request instance for DeleteSqlFilters.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.DeleteSqlFiltersRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.DeleteSqlFiltersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSqlFilters", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteSqlFiltersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAllUserContact(self, request):
         """获取邮件发送中联系人的相关信息。
 
@@ -232,7 +384,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAllUserContact", params)
+            headers = request.headers
+            body = self.call("DescribeAllUserContact", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAllUserContactResponse()
@@ -260,7 +413,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAllUserGroup", params)
+            headers = request.headers
+            body = self.call("DescribeAllUserGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAllUserGroupResponse()
@@ -288,7 +442,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBDiagEvent", params)
+            headers = request.headers
+            body = self.call("DescribeDBDiagEvent", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBDiagEventResponse()
@@ -306,6 +461,35 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDBDiagEvents(self, request):
+        """获取指定时间段内的诊断事件列表，支持依据风险等级、实例ID等条件过滤。
+
+        :param request: Request instance for DescribeDBDiagEvents.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeDBDiagEventsRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.DescribeDBDiagEventsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDBDiagEvents", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDBDiagEventsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDBDiagHistory(self, request):
         """获取实例诊断事件的列表。
 
@@ -316,7 +500,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBDiagHistory", params)
+            headers = request.headers
+            body = self.call("DescribeDBDiagHistory", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBDiagHistoryResponse()
@@ -344,7 +529,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBDiagReportTasks", params)
+            headers = request.headers
+            body = self.call("DescribeDBDiagReportTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBDiagReportTasksResponse()
@@ -372,7 +558,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBSpaceStatus", params)
+            headers = request.headers
+            body = self.call("DescribeDBSpaceStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBSpaceStatusResponse()
@@ -400,7 +587,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDiagDBInstances", params)
+            headers = request.headers
+            body = self.call("DescribeDiagDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDiagDBInstancesResponse()
@@ -428,7 +616,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeHealthScore", params)
+            headers = request.headers
+            body = self.call("DescribeHealthScore", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeHealthScoreResponse()
@@ -456,7 +645,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMailProfile", params)
+            headers = request.headers
+            body = self.call("DescribeMailProfile", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMailProfileResponse()
@@ -484,7 +674,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMySqlProcessList", params)
+            headers = request.headers
+            body = self.call("DescribeMySqlProcessList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMySqlProcessListResponse()
@@ -502,6 +693,93 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeNoPrimaryKeyTables(self, request):
+        """查询实例无主键表。
+
+        :param request: Request instance for DescribeNoPrimaryKeyTables.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeNoPrimaryKeyTablesRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.DescribeNoPrimaryKeyTablesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeNoPrimaryKeyTables", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeNoPrimaryKeyTablesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeProxySessionKillTasks(self, request):
+        """用于查询 redis 执行 kill 会话任务后代理节点的执行结果，入参异步任务 ID 从接口 CreateProxySessionKillTask 调用成功后取得。当前 product 只支持：redis。
+
+        :param request: Request instance for DescribeProxySessionKillTasks.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeProxySessionKillTasksRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.DescribeProxySessionKillTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeProxySessionKillTasks", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeProxySessionKillTasksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeRedisTopBigKeys(self, request):
+        """查询redis实例大key列表。
+
+        :param request: Request instance for DescribeRedisTopBigKeys.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeRedisTopBigKeysRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.DescribeRedisTopBigKeysResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRedisTopBigKeys", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeRedisTopBigKeysResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSecurityAuditLogDownloadUrls(self, request):
         """查询安全审计日志导出文件下载链接。目前日志文件下载仅提供腾讯云内网地址，请通过广州地域的腾讯云服务器进行下载。
 
@@ -512,7 +790,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSecurityAuditLogDownloadUrls", params)
+            headers = request.headers
+            body = self.call("DescribeSecurityAuditLogDownloadUrls", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSecurityAuditLogDownloadUrlsResponse()
@@ -540,7 +819,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSecurityAuditLogExportTasks", params)
+            headers = request.headers
+            body = self.call("DescribeSecurityAuditLogExportTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSecurityAuditLogExportTasksResponse()
@@ -568,7 +848,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowLogTimeSeriesStats", params)
+            headers = request.headers
+            body = self.call("DescribeSlowLogTimeSeriesStats", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowLogTimeSeriesStatsResponse()
@@ -596,7 +877,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowLogTopSqls", params)
+            headers = request.headers
+            body = self.call("DescribeSlowLogTopSqls", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowLogTopSqlsResponse()
@@ -624,7 +906,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowLogUserHostStats", params)
+            headers = request.headers
+            body = self.call("DescribeSlowLogUserHostStats", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowLogUserHostStatsResponse()
@@ -642,6 +925,64 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSqlFilters(self, request):
+        """查询实例SQL限流任务列表。
+
+        :param request: Request instance for DescribeSqlFilters.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeSqlFiltersRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.DescribeSqlFiltersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSqlFilters", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSqlFiltersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeSqlTemplate(self, request):
+        """查询SQL模版。
+
+        :param request: Request instance for DescribeSqlTemplate.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeSqlTemplateRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.DescribeSqlTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSqlTemplate", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSqlTemplateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTopSpaceSchemaTimeSeries(self, request):
         """获取实例占用空间最大的前几个库在指定时间段内的每日由DBbrain定时采集的空间数据，默认返回按大小排序。
 
@@ -652,7 +993,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopSpaceSchemaTimeSeries", params)
+            headers = request.headers
+            body = self.call("DescribeTopSpaceSchemaTimeSeries", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopSpaceSchemaTimeSeriesResponse()
@@ -680,7 +1022,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopSpaceSchemas", params)
+            headers = request.headers
+            body = self.call("DescribeTopSpaceSchemas", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopSpaceSchemasResponse()
@@ -708,7 +1051,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopSpaceTableTimeSeries", params)
+            headers = request.headers
+            body = self.call("DescribeTopSpaceTableTimeSeries", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopSpaceTableTimeSeriesResponse()
@@ -736,7 +1080,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopSpaceTables", params)
+            headers = request.headers
+            body = self.call("DescribeTopSpaceTables", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopSpaceTablesResponse()
@@ -755,7 +1100,7 @@ class DbbrainClient(AbstractClient):
 
 
     def DescribeUserSqlAdvice(self, request):
-        """获取SQL优化建议。
+        """获取SQL优化建议。【产品用户回馈，此接口限免开放，后续将并入dbbrain专业版】
 
         :param request: Request instance for DescribeUserSqlAdvice.
         :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeUserSqlAdviceRequest`
@@ -764,7 +1109,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUserSqlAdvice", params)
+            headers = request.headers
+            body = self.call("DescribeUserSqlAdvice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUserSqlAdviceResponse()
@@ -792,7 +1138,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("KillMySqlThreads", params)
+            headers = request.headers
+            body = self.call("KillMySqlThreads", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.KillMySqlThreadsResponse()
@@ -820,7 +1167,8 @@ class DbbrainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDiagDBInstanceConf", params)
+            headers = request.headers
+            body = self.call("ModifyDiagDBInstanceConf", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDiagDBInstanceConfResponse()
@@ -831,6 +1179,64 @@ class DbbrainClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifySqlFilters(self, request):
+        """更改实例限流任务状态，目前仅用于终止限流。
+
+        :param request: Request instance for ModifySqlFilters.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.ModifySqlFiltersRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.ModifySqlFiltersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifySqlFilters", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifySqlFiltersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def VerifyUserAccount(self, request):
+        """验证用户数据库账号权限，获取会话token。
+
+        :param request: Request instance for VerifyUserAccount.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.VerifyUserAccountRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.VerifyUserAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("VerifyUserAccount", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.VerifyUserAccountResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
